# Install with docker

```
docker exec -it <container_id> /bin/bash
```


# Ubuntu

```
sudo apt install openjdk-8-jdk

```


# Inside jenkins

```
echo "PATH=$HOME/.local/bin:$PATH" >> ~/.bashrc
source ~/.bashrource ~/.bashrc
```

References:
- https://wiki.jenkins.io/display/JENKINS/Installing+Jenkins+with+Docker
- https://wiki.jenkins.io/display/JENKINS/Installing+Jenkins+on+Ubuntu
